=======
History
=======

0.0.2 (2020-07-02)
------------------

* Fix opponent always fixed to 'negamax'.
* Introduce first test.
* Fix travis built.

0.0.1 (2020-07-01)
------------------

* Add ConnectorX to available environments.
* First release on PyPI.
